/* EventPage.c generated by valac 0.40.4, the Vala compiler
 * generated from EventPage.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */


#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <gee.h>
#include <gdk/gdk.h>
#include <glib/gi18n-lib.h>


#define TYPE_PAGE (page_get_type ())
#define PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE, Page))
#define PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE, PageClass))
#define IS_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE))
#define IS_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE))
#define PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE, PageClass))

typedef struct _Page Page;
typedef struct _PageClass PageClass;
typedef struct _PagePrivate PagePrivate;

#define TYPE_PAGE_WINDOW (page_window_get_type ())
#define PAGE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE_WINDOW, PageWindow))
#define PAGE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE_WINDOW, PageWindowClass))
#define IS_PAGE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE_WINDOW))
#define IS_PAGE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE_WINDOW))
#define PAGE_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE_WINDOW, PageWindowClass))

typedef struct _PageWindow PageWindow;
typedef struct _PageWindowClass PageWindowClass;

#define TYPE_FULLSCREEN_WINDOW (fullscreen_window_get_type ())
#define FULLSCREEN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_FULLSCREEN_WINDOW, FullscreenWindow))
#define FULLSCREEN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_FULLSCREEN_WINDOW, FullscreenWindowClass))
#define IS_FULLSCREEN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_FULLSCREEN_WINDOW))
#define IS_FULLSCREEN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_FULLSCREEN_WINDOW))
#define FULLSCREEN_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_FULLSCREEN_WINDOW, FullscreenWindowClass))

typedef struct _FullscreenWindow FullscreenWindow;
typedef struct _FullscreenWindowClass FullscreenWindowClass;

#define TYPE_INJECTION_GROUP (injection_group_get_type ())
#define INJECTION_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_INJECTION_GROUP, InjectionGroup))
#define INJECTION_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_INJECTION_GROUP, InjectionGroupClass))
#define IS_INJECTION_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_INJECTION_GROUP))
#define IS_INJECTION_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_INJECTION_GROUP))
#define INJECTION_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_INJECTION_GROUP, InjectionGroupClass))

typedef struct _InjectionGroup InjectionGroup;
typedef struct _InjectionGroupClass InjectionGroupClass;

#define TYPE_CHECKERBOARD_PAGE (checkerboard_page_get_type ())
#define CHECKERBOARD_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CHECKERBOARD_PAGE, CheckerboardPage))
#define CHECKERBOARD_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CHECKERBOARD_PAGE, CheckerboardPageClass))
#define IS_CHECKERBOARD_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CHECKERBOARD_PAGE))
#define IS_CHECKERBOARD_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CHECKERBOARD_PAGE))
#define CHECKERBOARD_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CHECKERBOARD_PAGE, CheckerboardPageClass))

typedef struct _CheckerboardPage CheckerboardPage;
typedef struct _CheckerboardPageClass CheckerboardPageClass;
typedef struct _CheckerboardPagePrivate CheckerboardPagePrivate;

#define TYPE_DATA_OBJECT (data_object_get_type ())
#define DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_OBJECT, DataObject))
#define DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_OBJECT, DataObjectClass))
#define IS_DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_OBJECT))
#define IS_DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_OBJECT))
#define DATA_OBJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_OBJECT, DataObjectClass))

typedef struct _DataObject DataObject;
typedef struct _DataObjectClass DataObjectClass;

#define TYPE_DATA_VIEW (data_view_get_type ())
#define DATA_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_VIEW, DataView))
#define DATA_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_VIEW, DataViewClass))
#define IS_DATA_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_VIEW))
#define IS_DATA_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_VIEW))
#define DATA_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_VIEW, DataViewClass))

typedef struct _DataView DataView;
typedef struct _DataViewClass DataViewClass;

#define TYPE_THUMBNAIL_VIEW (thumbnail_view_get_type ())
#define THUMBNAIL_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_THUMBNAIL_VIEW, ThumbnailView))
#define THUMBNAIL_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_THUMBNAIL_VIEW, ThumbnailViewClass))
#define IS_THUMBNAIL_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_THUMBNAIL_VIEW))
#define IS_THUMBNAIL_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_THUMBNAIL_VIEW))
#define THUMBNAIL_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_THUMBNAIL_VIEW, ThumbnailViewClass))

typedef struct _ThumbnailView ThumbnailView;
typedef struct _ThumbnailViewClass ThumbnailViewClass;

#define TYPE_CHECKERBOARD_ITEM (checkerboard_item_get_type ())
#define CHECKERBOARD_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CHECKERBOARD_ITEM, CheckerboardItem))
#define CHECKERBOARD_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CHECKERBOARD_ITEM, CheckerboardItemClass))
#define IS_CHECKERBOARD_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CHECKERBOARD_ITEM))
#define IS_CHECKERBOARD_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CHECKERBOARD_ITEM))
#define CHECKERBOARD_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CHECKERBOARD_ITEM, CheckerboardItemClass))

typedef struct _CheckerboardItem CheckerboardItem;
typedef struct _CheckerboardItemClass CheckerboardItemClass;

#define CHECKERBOARD_PAGE_TYPE_ACTIVATOR (checkerboard_page_activator_get_type ())

#define CHECKERBOARD_PAGE_TYPE_KEYBOARD_MODIFIERS (checkerboard_page_keyboard_modifiers_get_type ())
typedef struct _CheckerboardPageKeyboardModifiers CheckerboardPageKeyboardModifiers;

#define TYPE_VIEW_FILTER (view_filter_get_type ())
#define VIEW_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VIEW_FILTER, ViewFilter))
#define VIEW_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VIEW_FILTER, ViewFilterClass))
#define IS_VIEW_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VIEW_FILTER))
#define IS_VIEW_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VIEW_FILTER))
#define VIEW_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VIEW_FILTER, ViewFilterClass))

typedef struct _ViewFilter ViewFilter;
typedef struct _ViewFilterClass ViewFilterClass;

#define TYPE_SEARCH_VIEW_FILTER (search_view_filter_get_type ())
#define SEARCH_VIEW_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SEARCH_VIEW_FILTER, SearchViewFilter))
#define SEARCH_VIEW_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SEARCH_VIEW_FILTER, SearchViewFilterClass))
#define IS_SEARCH_VIEW_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SEARCH_VIEW_FILTER))
#define IS_SEARCH_VIEW_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SEARCH_VIEW_FILTER))
#define SEARCH_VIEW_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SEARCH_VIEW_FILTER, SearchViewFilterClass))

typedef struct _SearchViewFilter SearchViewFilter;
typedef struct _SearchViewFilterClass SearchViewFilterClass;

#define CORE_TYPE_TRACKER (core_tracker_get_type ())
#define CORE_TRACKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CORE_TYPE_TRACKER, CoreTracker))
#define CORE_TRACKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CORE_TYPE_TRACKER, CoreTrackerClass))
#define CORE_IS_TRACKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CORE_TYPE_TRACKER))
#define CORE_IS_TRACKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CORE_TYPE_TRACKER))
#define CORE_TRACKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CORE_TYPE_TRACKER, CoreTrackerClass))

typedef struct _CoreTracker CoreTracker;
typedef struct _CoreTrackerClass CoreTrackerClass;

#define CORE_TYPE_VIEW_TRACKER (core_view_tracker_get_type ())
#define CORE_VIEW_TRACKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CORE_TYPE_VIEW_TRACKER, CoreViewTracker))
#define CORE_VIEW_TRACKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CORE_TYPE_VIEW_TRACKER, CoreViewTrackerClass))
#define CORE_IS_VIEW_TRACKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CORE_TYPE_VIEW_TRACKER))
#define CORE_IS_VIEW_TRACKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CORE_TYPE_VIEW_TRACKER))
#define CORE_VIEW_TRACKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CORE_TYPE_VIEW_TRACKER, CoreViewTrackerClass))

typedef struct _CoreViewTracker CoreViewTracker;
typedef struct _CoreViewTrackerClass CoreViewTrackerClass;

#define TYPE_MEDIA_PAGE (media_page_get_type ())
#define MEDIA_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_PAGE, MediaPage))
#define MEDIA_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_PAGE, MediaPageClass))
#define IS_MEDIA_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_PAGE))
#define IS_MEDIA_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_PAGE))
#define MEDIA_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_PAGE, MediaPageClass))

typedef struct _MediaPage MediaPage;
typedef struct _MediaPageClass MediaPageClass;
typedef struct _MediaPagePrivate MediaPagePrivate;

#define TYPE_RATING (rating_get_type ())

#define TYPE_RAW_DEVELOPER (raw_developer_get_type ())

#define TYPE_DATA_SOURCE (data_source_get_type ())
#define DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_SOURCE, DataSource))
#define DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_SOURCE, DataSourceClass))
#define IS_DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_SOURCE))
#define IS_DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_SOURCE))
#define DATA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_SOURCE, DataSourceClass))

typedef struct _DataSource DataSource;
typedef struct _DataSourceClass DataSourceClass;

#define TYPE_COLLECTION_PAGE (collection_page_get_type ())
#define COLLECTION_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_COLLECTION_PAGE, CollectionPage))
#define COLLECTION_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_COLLECTION_PAGE, CollectionPageClass))
#define IS_COLLECTION_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_COLLECTION_PAGE))
#define IS_COLLECTION_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_COLLECTION_PAGE))
#define COLLECTION_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_COLLECTION_PAGE, CollectionPageClass))

typedef struct _CollectionPage CollectionPage;
typedef struct _CollectionPageClass CollectionPageClass;
typedef struct _CollectionPagePrivate CollectionPagePrivate;

#define TYPE_EVENT_PAGE (event_page_get_type ())
#define EVENT_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EVENT_PAGE, EventPage))
#define EVENT_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EVENT_PAGE, EventPageClass))
#define IS_EVENT_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EVENT_PAGE))
#define IS_EVENT_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EVENT_PAGE))
#define EVENT_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EVENT_PAGE, EventPageClass))

typedef struct _EventPage EventPage;
typedef struct _EventPageClass EventPageClass;
typedef struct _EventPagePrivate EventPagePrivate;

#define TYPE_THUMBNAIL_SOURCE (thumbnail_source_get_type ())
#define THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSource))
#define THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))
#define IS_THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_THUMBNAIL_SOURCE))
#define IS_THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_THUMBNAIL_SOURCE))
#define THUMBNAIL_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))

typedef struct _ThumbnailSource ThumbnailSource;
typedef struct _ThumbnailSourceClass ThumbnailSourceClass;

#define TYPE_EVENT_SOURCE (event_source_get_type ())
#define EVENT_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EVENT_SOURCE, EventSource))
#define EVENT_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EVENT_SOURCE, EventSourceClass))
#define IS_EVENT_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EVENT_SOURCE))
#define IS_EVENT_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EVENT_SOURCE))
#define EVENT_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EVENT_SOURCE, EventSourceClass))

typedef struct _EventSource EventSource;
typedef struct _EventSourceClass EventSourceClass;

#define TYPE_EVENT (event_get_type ())
#define EVENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EVENT, Event))
#define EVENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EVENT, EventClass))
#define IS_EVENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EVENT))
#define IS_EVENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EVENT))
#define EVENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EVENT, EventClass))

typedef struct _Event Event;
typedef struct _EventClass EventClass;
enum  {
	EVENT_PAGE_0_PROPERTY,
	EVENT_PAGE_NUM_PROPERTIES
};
static GParamSpec* event_page_properties[EVENT_PAGE_NUM_PROPERTIES];

#define TYPE_DATA_COLLECTION (data_collection_get_type ())
#define DATA_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_COLLECTION, DataCollection))
#define DATA_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_COLLECTION, DataCollectionClass))
#define IS_DATA_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_COLLECTION))
#define IS_DATA_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_COLLECTION))
#define DATA_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_COLLECTION, DataCollectionClass))

typedef struct _DataCollection DataCollection;
typedef struct _DataCollectionClass DataCollectionClass;

#define TYPE_SOURCE_COLLECTION (source_collection_get_type ())
#define SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SOURCE_COLLECTION, SourceCollection))
#define SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SOURCE_COLLECTION, SourceCollectionClass))
#define IS_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SOURCE_COLLECTION))
#define IS_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SOURCE_COLLECTION))
#define SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SOURCE_COLLECTION, SourceCollectionClass))

typedef struct _SourceCollection SourceCollection;
typedef struct _SourceCollectionClass SourceCollectionClass;

#define TYPE_DATABASE_SOURCE_COLLECTION (database_source_collection_get_type ())
#define DATABASE_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollection))
#define DATABASE_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollectionClass))
#define IS_DATABASE_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATABASE_SOURCE_COLLECTION))
#define IS_DATABASE_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATABASE_SOURCE_COLLECTION))
#define DATABASE_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollectionClass))

typedef struct _DatabaseSourceCollection DatabaseSourceCollection;
typedef struct _DatabaseSourceCollectionClass DatabaseSourceCollectionClass;

#define TYPE_CONTAINER_SOURCE_COLLECTION (container_source_collection_get_type ())
#define CONTAINER_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CONTAINER_SOURCE_COLLECTION, ContainerSourceCollection))
#define CONTAINER_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CONTAINER_SOURCE_COLLECTION, ContainerSourceCollectionClass))
#define IS_CONTAINER_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CONTAINER_SOURCE_COLLECTION))
#define IS_CONTAINER_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CONTAINER_SOURCE_COLLECTION))
#define CONTAINER_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CONTAINER_SOURCE_COLLECTION, ContainerSourceCollectionClass))

typedef struct _ContainerSourceCollection ContainerSourceCollection;
typedef struct _ContainerSourceCollectionClass ContainerSourceCollectionClass;

#define TYPE_EVENT_SOURCE_COLLECTION (event_source_collection_get_type ())
#define EVENT_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EVENT_SOURCE_COLLECTION, EventSourceCollection))
#define EVENT_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EVENT_SOURCE_COLLECTION, EventSourceCollectionClass))
#define IS_EVENT_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EVENT_SOURCE_COLLECTION))
#define IS_EVENT_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EVENT_SOURCE_COLLECTION))
#define EVENT_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EVENT_SOURCE_COLLECTION, EventSourceCollectionClass))

typedef struct _EventSourceCollection EventSourceCollection;
typedef struct _EventSourceCollectionClass EventSourceCollectionClass;

#define TYPE_ALTERATION (alteration_get_type ())
#define ALTERATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ALTERATION, Alteration))
#define ALTERATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ALTERATION, AlterationClass))
#define IS_ALTERATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ALTERATION))
#define IS_ALTERATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ALTERATION))
#define ALTERATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ALTERATION, AlterationClass))

typedef struct _Alteration Alteration;
typedef struct _AlterationClass AlterationClass;

#define TYPE_VIEW_COLLECTION (view_collection_get_type ())
#define VIEW_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VIEW_COLLECTION, ViewCollection))
#define VIEW_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VIEW_COLLECTION, ViewCollectionClass))
#define IS_VIEW_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VIEW_COLLECTION))
#define IS_VIEW_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VIEW_COLLECTION))
#define VIEW_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VIEW_COLLECTION, ViewCollectionClass))

typedef struct _ViewCollection ViewCollection;
typedef struct _ViewCollectionClass ViewCollectionClass;
#define _data_collection_unref0(var) ((var == NULL) ? NULL : (var = (data_collection_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

#define TYPE_CONFIGURATION_FACADE (configuration_facade_get_type ())
#define CONFIGURATION_FACADE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CONFIGURATION_FACADE, ConfigurationFacade))
#define CONFIGURATION_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CONFIGURATION_FACADE, ConfigurationFacadeClass))
#define IS_CONFIGURATION_FACADE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CONFIGURATION_FACADE))
#define IS_CONFIGURATION_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CONFIGURATION_FACADE))
#define CONFIGURATION_FACADE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CONFIGURATION_FACADE, ConfigurationFacadeClass))

typedef struct _ConfigurationFacade ConfigurationFacade;
typedef struct _ConfigurationFacadeClass ConfigurationFacadeClass;

#define CONFIG_TYPE_FACADE (config_facade_get_type ())
#define CONFIG_FACADE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONFIG_TYPE_FACADE, ConfigFacade))
#define CONFIG_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONFIG_TYPE_FACADE, ConfigFacadeClass))
#define CONFIG_IS_FACADE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONFIG_TYPE_FACADE))
#define CONFIG_IS_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONFIG_TYPE_FACADE))
#define CONFIG_FACADE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONFIG_TYPE_FACADE, ConfigFacadeClass))

typedef struct _ConfigFacade ConfigFacade;
typedef struct _ConfigFacadeClass ConfigFacadeClass;

#define TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR (multi_text_entry_dialog_mediator_get_type ())
#define MULTI_TEXT_ENTRY_DIALOG_MEDIATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR, MultiTextEntryDialogMediator))
#define MULTI_TEXT_ENTRY_DIALOG_MEDIATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR, MultiTextEntryDialogMediatorClass))
#define IS_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR))
#define IS_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR))
#define MULTI_TEXT_ENTRY_DIALOG_MEDIATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR, MultiTextEntryDialogMediatorClass))

typedef struct _MultiTextEntryDialogMediator MultiTextEntryDialogMediator;
typedef struct _MultiTextEntryDialogMediatorClass MultiTextEntryDialogMediatorClass;

#define TYPE_EDIT_COMMENT_DIALOG (edit_comment_dialog_get_type ())
#define EDIT_COMMENT_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EDIT_COMMENT_DIALOG, EditCommentDialog))
#define EDIT_COMMENT_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EDIT_COMMENT_DIALOG, EditCommentDialogClass))
#define IS_EDIT_COMMENT_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EDIT_COMMENT_DIALOG))
#define IS_EDIT_COMMENT_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EDIT_COMMENT_DIALOG))
#define EDIT_COMMENT_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EDIT_COMMENT_DIALOG, EditCommentDialogClass))

typedef struct _EditCommentDialog EditCommentDialog;
typedef struct _EditCommentDialogClass EditCommentDialogClass;
#define _multi_text_entry_dialog_mediator_unref0(var) ((var == NULL) ? NULL : (var = (multi_text_entry_dialog_mediator_unref (var), NULL)))

#define TYPE_COMMAND (command_get_type ())
#define COMMAND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_COMMAND, Command))
#define COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_COMMAND, CommandClass))
#define IS_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_COMMAND))
#define IS_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_COMMAND))
#define COMMAND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_COMMAND, CommandClass))

typedef struct _Command Command;
typedef struct _CommandClass CommandClass;

#define TYPE_PAGE_COMMAND (page_command_get_type ())
#define PAGE_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE_COMMAND, PageCommand))
#define PAGE_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE_COMMAND, PageCommandClass))
#define IS_PAGE_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE_COMMAND))
#define IS_PAGE_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE_COMMAND))
#define PAGE_COMMAND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE_COMMAND, PageCommandClass))

typedef struct _PageCommand PageCommand;
typedef struct _PageCommandClass PageCommandClass;

#define TYPE_SIMPLE_PROXYABLE_COMMAND (simple_proxyable_command_get_type ())
#define SIMPLE_PROXYABLE_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SIMPLE_PROXYABLE_COMMAND, SimpleProxyableCommand))
#define SIMPLE_PROXYABLE_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SIMPLE_PROXYABLE_COMMAND, SimpleProxyableCommandClass))
#define IS_SIMPLE_PROXYABLE_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SIMPLE_PROXYABLE_COMMAND))
#define IS_SIMPLE_PROXYABLE_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SIMPLE_PROXYABLE_COMMAND))
#define SIMPLE_PROXYABLE_COMMAND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SIMPLE_PROXYABLE_COMMAND, SimpleProxyableCommandClass))

typedef struct _SimpleProxyableCommand SimpleProxyableCommand;
typedef struct _SimpleProxyableCommandClass SimpleProxyableCommandClass;

#define TYPE_EDIT_EVENT_COMMENT_COMMAND (edit_event_comment_command_get_type ())
#define EDIT_EVENT_COMMENT_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EDIT_EVENT_COMMENT_COMMAND, EditEventCommentCommand))
#define EDIT_EVENT_COMMENT_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EDIT_EVENT_COMMENT_COMMAND, EditEventCommentCommandClass))
#define IS_EDIT_EVENT_COMMENT_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EDIT_EVENT_COMMENT_COMMAND))
#define IS_EDIT_EVENT_COMMENT_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EDIT_EVENT_COMMENT_COMMAND))
#define EDIT_EVENT_COMMENT_COMMAND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EDIT_EVENT_COMMENT_COMMAND, EditEventCommentCommandClass))

typedef struct _EditEventCommentCommand EditEventCommentCommand;
typedef struct _EditEventCommentCommandClass EditEventCommentCommandClass;

#define TYPE_COMMAND_MANAGER (command_manager_get_type ())
#define COMMAND_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_COMMAND_MANAGER, CommandManager))
#define COMMAND_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_COMMAND_MANAGER, CommandManagerClass))
#define IS_COMMAND_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_COMMAND_MANAGER))
#define IS_COMMAND_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_COMMAND_MANAGER))
#define COMMAND_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_COMMAND_MANAGER, CommandManagerClass))

typedef struct _CommandManager CommandManager;
typedef struct _CommandManagerClass CommandManagerClass;
#define _command_manager_unref0(var) ((var == NULL) ? NULL : (var = (command_manager_unref (var), NULL)))

#define TYPE_MEDIA_SOURCE (media_source_get_type ())
#define MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE, MediaSource))
#define MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE, MediaSourceClass))
#define IS_MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE))
#define IS_MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE))
#define MEDIA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE, MediaSourceClass))

typedef struct _MediaSource MediaSource;
typedef struct _MediaSourceClass MediaSourceClass;

#define TYPE_APP_WINDOW (app_window_get_type ())
#define APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_APP_WINDOW, AppWindow))
#define APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_APP_WINDOW, AppWindowClass))
#define IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_APP_WINDOW))
#define IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_APP_WINDOW))
#define APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_APP_WINDOW, AppWindowClass))

typedef struct _AppWindow AppWindow;
typedef struct _AppWindowClass AppWindowClass;

#define TYPE_LIBRARY_WINDOW (library_window_get_type ())
#define LIBRARY_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LIBRARY_WINDOW, LibraryWindow))
#define LIBRARY_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LIBRARY_WINDOW, LibraryWindowClass))
#define IS_LIBRARY_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LIBRARY_WINDOW))
#define IS_LIBRARY_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LIBRARY_WINDOW))
#define LIBRARY_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LIBRARY_WINDOW, LibraryWindowClass))

typedef struct _LibraryWindow LibraryWindow;
typedef struct _LibraryWindowClass LibraryWindowClass;

#define TYPE_NO_EVENT_PAGE (no_event_page_get_type ())
#define NO_EVENT_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_NO_EVENT_PAGE, NoEventPage))
#define NO_EVENT_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_NO_EVENT_PAGE, NoEventPageClass))
#define IS_NO_EVENT_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_NO_EVENT_PAGE))
#define IS_NO_EVENT_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_NO_EVENT_PAGE))
#define NO_EVENT_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_NO_EVENT_PAGE, NoEventPageClass))

typedef struct _NoEventPage NoEventPage;
typedef struct _NoEventPageClass NoEventPageClass;
typedef struct _NoEventPagePrivate NoEventPagePrivate;
enum  {
	NO_EVENT_PAGE_0_PROPERTY,
	NO_EVENT_PAGE_NUM_PROPERTIES
};
static GParamSpec* no_event_page_properties[NO_EVENT_PAGE_NUM_PROPERTIES];

#define TYPE_VIEW_MANAGER (view_manager_get_type ())
#define VIEW_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VIEW_MANAGER, ViewManager))
#define VIEW_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VIEW_MANAGER, ViewManagerClass))
#define IS_VIEW_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VIEW_MANAGER))
#define IS_VIEW_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VIEW_MANAGER))
#define VIEW_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VIEW_MANAGER, ViewManagerClass))

typedef struct _ViewManager ViewManager;
typedef struct _ViewManagerClass ViewManagerClass;

#define TYPE_COLLECTION_VIEW_MANAGER (collection_view_manager_get_type ())
#define COLLECTION_VIEW_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_COLLECTION_VIEW_MANAGER, CollectionViewManager))
#define COLLECTION_VIEW_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_COLLECTION_VIEW_MANAGER, CollectionViewManagerClass))
#define IS_COLLECTION_VIEW_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_COLLECTION_VIEW_MANAGER))
#define IS_COLLECTION_VIEW_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_COLLECTION_VIEW_MANAGER))
#define COLLECTION_VIEW_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_COLLECTION_VIEW_MANAGER, CollectionViewManagerClass))

typedef struct _CollectionViewManager CollectionViewManager;
typedef struct _CollectionViewManagerClass CollectionViewManagerClass;

#define NO_EVENT_PAGE_TYPE_NO_EVENT_VIEW_MANAGER (no_event_page_no_event_view_manager_get_type ())
#define NO_EVENT_PAGE_NO_EVENT_VIEW_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), NO_EVENT_PAGE_TYPE_NO_EVENT_VIEW_MANAGER, NoEventPageNoEventViewManager))
#define NO_EVENT_PAGE_NO_EVENT_VIEW_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), NO_EVENT_PAGE_TYPE_NO_EVENT_VIEW_MANAGER, NoEventPageNoEventViewManagerClass))
#define NO_EVENT_PAGE_IS_NO_EVENT_VIEW_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), NO_EVENT_PAGE_TYPE_NO_EVENT_VIEW_MANAGER))
#define NO_EVENT_PAGE_IS_NO_EVENT_VIEW_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), NO_EVENT_PAGE_TYPE_NO_EVENT_VIEW_MANAGER))
#define NO_EVENT_PAGE_NO_EVENT_VIEW_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), NO_EVENT_PAGE_TYPE_NO_EVENT_VIEW_MANAGER, NoEventPageNoEventViewManagerClass))

typedef struct _NoEventPageNoEventViewManager NoEventPageNoEventViewManager;
typedef struct _NoEventPageNoEventViewManagerClass NoEventPageNoEventViewManagerClass;

#define VIEW_COLLECTION_TYPE_MONITOR (view_collection_monitor_get_type ())
#define VIEW_COLLECTION_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VIEW_COLLECTION_TYPE_MONITOR, ViewCollectionMonitor))
#define VIEW_COLLECTION_MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VIEW_COLLECTION_TYPE_MONITOR, ViewCollectionMonitorClass))
#define VIEW_COLLECTION_IS_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VIEW_COLLECTION_TYPE_MONITOR))
#define VIEW_COLLECTION_IS_MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VIEW_COLLECTION_TYPE_MONITOR))
#define VIEW_COLLECTION_MONITOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VIEW_COLLECTION_TYPE_MONITOR, ViewCollectionMonitorClass))

typedef struct _ViewCollectionMonitor ViewCollectionMonitor;
typedef struct _ViewCollectionMonitorClass ViewCollectionMonitorClass;

#define TYPE_MEDIA_SOURCE_COLLECTION (media_source_collection_get_type ())
#define MEDIA_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection))
#define MEDIA_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollectionClass))
#define IS_MEDIA_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE_COLLECTION))
#define IS_MEDIA_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE_COLLECTION))
#define MEDIA_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollectionClass))

typedef struct _MediaSourceCollection MediaSourceCollection;
typedef struct _MediaSourceCollectionClass MediaSourceCollectionClass;

#define TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION (library_photo_source_collection_get_type ())
#define LIBRARY_PHOTO_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollection))
#define LIBRARY_PHOTO_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollectionClass))
#define IS_LIBRARY_PHOTO_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION))
#define IS_LIBRARY_PHOTO_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION))
#define LIBRARY_PHOTO_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollectionClass))

typedef struct _LibraryPhotoSourceCollection LibraryPhotoSourceCollection;
typedef struct _LibraryPhotoSourceCollectionClass LibraryPhotoSourceCollectionClass;
#define _view_collection_monitor_unref0(var) ((var == NULL) ? NULL : (var = (view_collection_monitor_unref (var), NULL)))

#define TYPE_VIDEO_SOURCE_COLLECTION (video_source_collection_get_type ())
#define VIDEO_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VIDEO_SOURCE_COLLECTION, VideoSourceCollection))
#define VIDEO_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VIDEO_SOURCE_COLLECTION, VideoSourceCollectionClass))
#define IS_VIDEO_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VIDEO_SOURCE_COLLECTION))
#define IS_VIDEO_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VIDEO_SOURCE_COLLECTION))
#define VIDEO_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VIDEO_SOURCE_COLLECTION, VideoSourceCollectionClass))

typedef struct _VideoSourceCollection VideoSourceCollection;
typedef struct _VideoSourceCollectionClass VideoSourceCollectionClass;
#define _view_manager_unref0(var) ((var == NULL) ? NULL : (var = (view_manager_unref (var), NULL)))
typedef struct _ViewManagerPrivate ViewManagerPrivate;
typedef struct _CollectionViewManagerPrivate CollectionViewManagerPrivate;
typedef struct _NoEventPageNoEventViewManagerPrivate NoEventPageNoEventViewManagerPrivate;

#define TYPE_EVENT_ID (event_id_get_type ())
typedef struct _EventID EventID;

struct _Page {
	GtkScrolledWindow parent_instance;
	PagePrivate * priv;
	GtkBuilder* builder;
	GtkToolbar* toolbar;
	gboolean in_view;
};

struct _PageClass {
	GtkScrolledWindowClass parent_class;
	void (*set_page_name) (Page* self, const gchar* page_name);
	void (*set_container) (Page* self, GtkWindow* container);
	void (*clear_container) (Page* self);
	GtkToolbar* (*get_toolbar) (Page* self);
	GtkMenu* (*get_page_context_menu) (Page* self);
	void (*switching_from) (Page* self);
	void (*switched_to) (Page* self);
	void (*ready) (Page* self);
	void (*switching_to_fullscreen) (Page* self, FullscreenWindow* fsw);
	void (*returning_from_fullscreen) (Page* self, FullscreenWindow* fsw);
	void (*add_actions) (Page* self, GActionMap* map);
	void (*remove_actions) (Page* self, GActionMap* map);
	void (*init_collect_ui_filenames) (Page* self, GeeList* ui_filenames);
	InjectionGroup** (*init_collect_injection_groups) (Page* self, int* result_length1);
	void (*init_actions) (Page* self, gint selected_count, gint count);
	void (*update_actions) (Page* self, gint selected_count, gint count);
	gboolean (*source_drag_failed) (Page* self, GdkDragContext* context, GtkDragResult drag_result);
	gboolean (*on_left_click) (Page* self, GdkEventButton* event);
	gboolean (*on_middle_click) (Page* self, GdkEventButton* event);
	gboolean (*on_right_click) (Page* self, GdkEventButton* event);
	gboolean (*on_left_released) (Page* self, GdkEventButton* event);
	gboolean (*on_middle_released) (Page* self, GdkEventButton* event);
	gboolean (*on_right_released) (Page* self, GdkEventButton* event);
	gboolean (*on_ctrl_pressed) (Page* self, GdkEventKey* event);
	gboolean (*on_ctrl_released) (Page* self, GdkEventKey* event);
	gboolean (*on_alt_pressed) (Page* self, GdkEventKey* event);
	gboolean (*on_alt_released) (Page* self, GdkEventKey* event);
	gboolean (*on_shift_pressed) (Page* self, GdkEventKey* event);
	gboolean (*on_shift_released) (Page* self, GdkEventKey* event);
	gboolean (*on_super_pressed) (Page* self, GdkEventKey* event);
	gboolean (*on_super_released) (Page* self, GdkEventKey* event);
	gboolean (*on_app_key_pressed) (Page* self, GdkEventKey* event);
	gboolean (*on_app_key_released) (Page* self, GdkEventKey* event);
	void (*on_move) (Page* self, GdkRectangle* rect);
	void (*on_move_start) (Page* self, GdkRectangle* rect);
	void (*on_move_finished) (Page* self, GdkRectangle* rect);
	void (*on_resize) (Page* self, GdkRectangle* rect);
	void (*on_resize_start) (Page* self, GdkRectangle* rect);
	void (*on_resize_finished) (Page* self, GdkRectangle* rect);
	gboolean (*on_configure) (Page* self, GdkEventConfigure* event, GdkRectangle* rect);
	gboolean (*on_motion) (Page* self, GdkEventMotion* event, gint x, gint y, GdkModifierType mask);
	gboolean (*on_leave_notify_event) (Page* self);
	gboolean (*on_mousewheel_up) (Page* self, GdkEventScroll* event);
	gboolean (*on_mousewheel_down) (Page* self, GdkEventScroll* event);
	gboolean (*on_mousewheel_left) (Page* self, GdkEventScroll* event);
	gboolean (*on_mousewheel_right) (Page* self, GdkEventScroll* event);
	gboolean (*on_context_keypress) (Page* self);
	gboolean (*on_context_buttonpress) (Page* self, GdkEventButton* event);
	gboolean (*on_context_invoked) (Page* self);
	void (*set_page_cursor) (Page* self, GdkCursorType cursor_type);
};

typedef enum  {
	CHECKERBOARD_PAGE_ACTIVATOR_KEYBOARD,
	CHECKERBOARD_PAGE_ACTIVATOR_MOUSE
} CheckerboardPageActivator;

struct _CheckerboardPageKeyboardModifiers {
	gboolean ctrl_pressed;
	gboolean alt_pressed;
	gboolean shift_pressed;
	gboolean super_pressed;
};

struct _CheckerboardPage {
	Page parent_instance;
	CheckerboardPagePrivate * priv;
	CheckerboardItem* anchor;
	CheckerboardItem* cursor;
};

struct _CheckerboardPageClass {
	PageClass parent_class;
	GtkMenu* (*get_item_context_menu) (CheckerboardPage* self);
	gchar* (*get_view_empty_message) (CheckerboardPage* self);
	gchar* (*get_filter_no_match_message) (CheckerboardPage* self);
	void (*on_item_activated) (CheckerboardPage* self, CheckerboardItem* item, CheckerboardPageActivator activator, CheckerboardPageKeyboardModifiers* modifiers);
	SearchViewFilter* (*get_search_view_filter) (CheckerboardPage* self);
	CoreViewTracker* (*get_view_tracker) (CheckerboardPage* self);
	gboolean (*on_mouse_over) (CheckerboardPage* self, CheckerboardItem* item, gint x, gint y, GdkModifierType mask);
	void (*set_display_titles) (CheckerboardPage* self, gboolean display);
	void (*set_display_comments) (CheckerboardPage* self, gboolean display);
};

typedef enum  {
	RATING_REJECTED = -1,
	RATING_UNRATED = 0,
	RATING_ONE = 1,
	RATING_TWO = 2,
	RATING_THREE = 3,
	RATING_FOUR = 4,
	RATING_FIVE = 5
} Rating;

typedef enum  {
	RAW_DEVELOPER_SHOTWELL = 0,
	RAW_DEVELOPER_CAMERA,
	RAW_DEVELOPER_EMBEDDED
} RawDeveloper;

struct _MediaPage {
	CheckerboardPage parent_instance;
	MediaPagePrivate * priv;
};

struct _MediaPageClass {
	CheckerboardPageClass parent_class;
	void (*on_zoom_changed) (MediaPage* self);
	void (*on_export) (MediaPage* self);
	void (*on_increase_size) (MediaPage* self);
	void (*on_decrease_size) (MediaPage* self);
	void (*on_increase_rating) (MediaPage* self);
	void (*on_decrease_rating) (MediaPage* self);
	void (*on_set_rating) (MediaPage* self, Rating rating);
	void (*on_rate_rejected) (MediaPage* self);
	void (*on_rate_unrated) (MediaPage* self);
	void (*on_rate_one) (MediaPage* self);
	void (*on_rate_two) (MediaPage* self);
	void (*on_rate_three) (MediaPage* self);
	void (*on_rate_four) (MediaPage* self);
	void (*on_rate_five) (MediaPage* self);
	void (*on_move_to_trash) (MediaPage* self);
	void (*on_edit_title) (MediaPage* self);
	void (*on_edit_comment) (MediaPage* self);
	void (*on_display_titles) (MediaPage* self, GSimpleAction* action, GVariant* value);
	void (*on_display_comments) (MediaPage* self, GSimpleAction* action, GVariant* value);
	void (*on_display_ratings) (MediaPage* self, GSimpleAction* action, GVariant* value);
	void (*on_display_tags) (MediaPage* self, GSimpleAction* action, GVariant* value);
	void (*get_config_photos_sort) (MediaPage* self, gboolean* sort_order, gint* sort_by);
	void (*set_config_photos_sort) (MediaPage* self, gboolean sort_order, gint sort_by);
	void (*on_sort_changed) (MediaPage* self, GSimpleAction* action, GVariant* value);
	void (*developer_changed) (MediaPage* self, RawDeveloper rd);
	DataView* (*create_thumbnail) (MediaPage* self, DataSource* source);
};

struct _CollectionPage {
	MediaPage parent_instance;
	CollectionPagePrivate * priv;
};

struct _CollectionPageClass {
	MediaPageClass parent_class;
};

struct _EventPage {
	CollectionPage parent_instance;
	EventPagePrivate * priv;
};

struct _EventPageClass {
	CollectionPageClass parent_class;
};

struct _EventPagePrivate {
	Event* page_event;
};

typedef DataView* (*CreateView) (DataSource* source, void* user_data);
struct _NoEventPage {
	CollectionPage parent_instance;
	NoEventPagePrivate * priv;
};

struct _NoEventPageClass {
	CollectionPageClass parent_class;
};

typedef gboolean (*ProgressMonitor) (guint64 current, guint64 total, gboolean do_event_loop, void* user_data);
struct _ViewManager {
	GTypeInstance parent_instance;
	volatile int ref_count;
	ViewManagerPrivate * priv;
};

struct _ViewManagerClass {
	GTypeClass parent_class;
	void (*finalize) (ViewManager *self);
	gboolean (*include_in_view) (ViewManager* self, DataSource* source);
	DataView* (*create_view) (ViewManager* self, DataSource* source);
};

struct _CollectionViewManager {
	ViewManager parent_instance;
	CollectionViewManagerPrivate * priv;
};

struct _CollectionViewManagerClass {
	ViewManagerClass parent_class;
};

struct _NoEventPageNoEventViewManager {
	CollectionViewManager parent_instance;
	NoEventPageNoEventViewManagerPrivate * priv;
};

struct _NoEventPageNoEventViewManagerClass {
	CollectionViewManagerClass parent_class;
};

struct _EventID {
	gint64 id;
};


static gpointer event_page_parent_class = NULL;
extern EventSourceCollection* event_global;
static gpointer no_event_page_parent_class = NULL;
static Alteration* no_event_page_no_event_page_alteration;
static Alteration* no_event_page_no_event_page_alteration = NULL;
extern LibraryPhotoSourceCollection* library_photo_global;
extern VideoSourceCollection* video_global;
static gpointer no_event_page_no_event_view_manager_parent_class = NULL;

GType page_get_type (void) G_GNUC_CONST;
GType page_window_get_type (void) G_GNUC_CONST;
GType fullscreen_window_get_type (void) G_GNUC_CONST;
gpointer injection_group_ref (gpointer instance);
void injection_group_unref (gpointer instance);
GParamSpec* param_spec_injection_group (const gchar* name,
                                        const gchar* nick,
                                        const gchar* blurb,
                                        GType object_type,
                                        GParamFlags flags);
void value_set_injection_group (GValue* value,
                                gpointer v_object);
void value_take_injection_group (GValue* value,
                                 gpointer v_object);
gpointer value_get_injection_group (const GValue* value);
GType injection_group_get_type (void) G_GNUC_CONST;
GType checkerboard_page_get_type (void) G_GNUC_CONST;
GType data_object_get_type (void) G_GNUC_CONST;
GType data_view_get_type (void) G_GNUC_CONST;
GType thumbnail_view_get_type (void) G_GNUC_CONST;
GType checkerboard_item_get_type (void) G_GNUC_CONST;
GType checkerboard_page_activator_get_type (void) G_GNUC_CONST;
GType checkerboard_page_keyboard_modifiers_get_type (void) G_GNUC_CONST;
CheckerboardPageKeyboardModifiers* checkerboard_page_keyboard_modifiers_dup (const CheckerboardPageKeyboardModifiers* self);
void checkerboard_page_keyboard_modifiers_free (CheckerboardPageKeyboardModifiers* self);
gpointer view_filter_ref (gpointer instance);
void view_filter_unref (gpointer instance);
GParamSpec* param_spec_view_filter (const gchar* name,
                                    const gchar* nick,
                                    const gchar* blurb,
                                    GType object_type,
                                    GParamFlags flags);
void value_set_view_filter (GValue* value,
                            gpointer v_object);
void value_take_view_filter (GValue* value,
                             gpointer v_object);
gpointer value_get_view_filter (const GValue* value);
GType view_filter_get_type (void) G_GNUC_CONST;
GType search_view_filter_get_type (void) G_GNUC_CONST;
gpointer core_tracker_ref (gpointer instance);
void core_tracker_unref (gpointer instance);
GParamSpec* core_param_spec_tracker (const gchar* name,
                                     const gchar* nick,
                                     const gchar* blurb,
                                     GType object_type,
                                     GParamFlags flags);
void core_value_set_tracker (GValue* value,
                             gpointer v_object);
void core_value_take_tracker (GValue* value,
                              gpointer v_object);
gpointer core_value_get_tracker (const GValue* value);
GType core_tracker_get_type (void) G_GNUC_CONST;
GType core_view_tracker_get_type (void) G_GNUC_CONST;
GType media_page_get_type (void) G_GNUC_CONST;
GType rating_get_type (void) G_GNUC_CONST;
GType raw_developer_get_type (void) G_GNUC_CONST;
GType data_source_get_type (void) G_GNUC_CONST;
GType collection_page_get_type (void) G_GNUC_CONST;
GType event_page_get_type (void) G_GNUC_CONST;
GType thumbnail_source_get_type (void) G_GNUC_CONST;
GType event_source_get_type (void) G_GNUC_CONST;
GType event_get_type (void) G_GNUC_CONST;
#define EVENT_PAGE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_EVENT_PAGE, EventPagePrivate))
gpointer data_collection_ref (gpointer instance);
void data_collection_unref (gpointer instance);
GParamSpec* param_spec_data_collection (const gchar* name,
                                        const gchar* nick,
                                        const gchar* blurb,
                                        GType object_type,
                                        GParamFlags flags);
void value_set_data_collection (GValue* value,
                                gpointer v_object);
void value_take_data_collection (GValue* value,
                                 gpointer v_object);
gpointer value_get_data_collection (const GValue* value);
GType data_collection_get_type (void) G_GNUC_CONST;
GType source_collection_get_type (void) G_GNUC_CONST;
GType database_source_collection_get_type (void) G_GNUC_CONST;
GType container_source_collection_get_type (void) G_GNUC_CONST;
GType event_source_collection_get_type (void) G_GNUC_CONST;
gpointer alteration_ref (gpointer instance);
void alteration_unref (gpointer instance);
GParamSpec* param_spec_alteration (const gchar* name,
                                   const gchar* nick,
                                   const gchar* blurb,
                                   GType object_type,
                                   GParamFlags flags);
void value_set_alteration (GValue* value,
                           gpointer v_object);
void value_take_alteration (GValue* value,
                            gpointer v_object);
gpointer value_get_alteration (const GValue* value);
GType alteration_get_type (void) G_GNUC_CONST;
static void event_page_on_events_altered (EventPage* self,
                                   GeeMap* map);
static void _event_page_on_events_altered_data_collection_items_altered (DataCollection* _sender,
                                                                  GeeMap* items,
                                                                  gpointer self);
GType view_collection_get_type (void) G_GNUC_CONST;
ViewCollection* page_get_view (Page* self);
void view_collection_halt_mirroring (ViewCollection* self);
static void event_page_on_make_primary (EventPage* self);
static void _event_page_on_make_primary_gsimple_action_activate_callback (GSimpleAction* action,
                                                                   GVariant* parameter,
                                                                   gpointer self);
static void event_page_on_rename (EventPage* self);
static void _event_page_on_rename_gsimple_action_activate_callback (GSimpleAction* action,
                                                             GVariant* parameter,
                                                             gpointer self);
void media_page_on_edit_comment (MediaPage* self);
static void _media_page_on_edit_comment_gsimple_action_activate_callback (GSimpleAction* action,
                                                                   GVariant* parameter,
                                                                   gpointer self);
EventPage* event_page_new (Event* page_event);
EventPage* event_page_construct (GType object_type,
                                 Event* page_event);
gchar* data_object_get_name (DataObject* self);
CollectionPage* collection_page_construct (GType object_type,
                                           const gchar* page_name);
void event_mirror_photos (Event* self,
                          ViewCollection* view,
                          CreateView mirroring_ctor,
                          void* mirroring_ctor_target);
DataView* media_page_create_thumbnail (MediaPage* self,
                                       DataSource* source);
static DataView* _media_page_create_thumbnail_create_view (DataSource* source,
                                                    gpointer self);
void checkerboard_page_init_page_context_menu (CheckerboardPage* self,
                                               const gchar* path);
Event* event_page_get_event (EventPage* self);
static gboolean event_page_real_on_app_key_pressed (Page* base,
                                             GdkEventKey* event);
gint view_collection_get_selected_count (ViewCollection* self);
gboolean page_on_app_key_pressed (Page* self,
                                  GdkEventKey* event);
static void event_page_real_init_collect_ui_filenames (Page* base,
                                                GeeList* ui_filenames);
void page_init_collect_ui_filenames (Page* self,
                                     GeeList* ui_filenames);
static void event_page_real_add_actions (Page* base,
                                  GActionMap* map);
void page_add_actions (Page* self,
                       GActionMap* map);
static void event_page_real_remove_actions (Page* base,
                                     GActionMap* map);
void page_remove_actions (Page* self,
                          GActionMap* map);
static void event_page_real_init_actions (Page* base,
                                   gint selected_count,
                                   gint count);
void page_init_actions (Page* self,
                        gint selected_count,
                        gint count);
static void event_page_real_update_actions (Page* base,
                                     gint selected_count,
                                     gint count);
void page_set_action_sensitive (Page* self,
                                const gchar* name,
                                gboolean sensitive);
void page_update_actions (Page* self,
                          gint selected_count,
                          gint count);
static void event_page_real_get_config_photos_sort (MediaPage* base,
                                             gboolean* sort_order,
                                             gint* sort_by);
GType configuration_facade_get_type (void) G_GNUC_CONST;
GType config_facade_get_type (void) G_GNUC_CONST;
ConfigFacade* config_facade_get_instance (void);
void configuration_facade_get_event_photos_sort (ConfigurationFacade* self,
                                                 gboolean* sort_order,
                                                 gint* sort_by);
static void event_page_real_set_config_photos_sort (MediaPage* base,
                                             gboolean sort_order,
                                             gint sort_by);
void configuration_facade_set_event_photos_sort (ConfigurationFacade* self,
                                                 gboolean sort_order,
                                                 gint sort_by);
void page_set_page_name (Page* self,
                         const gchar* page_name);
static void event_page_real_on_edit_comment (MediaPage* base);
gpointer multi_text_entry_dialog_mediator_ref (gpointer instance);
void multi_text_entry_dialog_mediator_unref (gpointer instance);
GParamSpec* param_spec_multi_text_entry_dialog_mediator (const gchar* name,
                                                         const gchar* nick,
                                                         const gchar* blurb,
                                                         GType object_type,
                                                         GParamFlags flags);
void value_set_multi_text_entry_dialog_mediator (GValue* value,
                                                 gpointer v_object);
void value_take_multi_text_entry_dialog_mediator (GValue* value,
                                                  gpointer v_object);
gpointer value_get_multi_text_entry_dialog_mediator (const GValue* value);
GType multi_text_entry_dialog_mediator_get_type (void) G_GNUC_CONST;
GType edit_comment_dialog_get_type (void) G_GNUC_CONST;
gchar* event_source_get_comment (EventSource* self);
EditCommentDialog* edit_comment_dialog_new (const gchar* comment,
                                            gboolean is_event);
EditCommentDialog* edit_comment_dialog_construct (GType object_type,
                                                  const gchar* comment,
                                                  gboolean is_event);
gchar* edit_comment_dialog_execute (EditCommentDialog* self);
GType command_get_type (void) G_GNUC_CONST;
GType page_command_get_type (void) G_GNUC_CONST;
GType simple_proxyable_command_get_type (void) G_GNUC_CONST;
GType edit_event_comment_command_get_type (void) G_GNUC_CONST;
EditEventCommentCommand* edit_event_comment_command_new (Event* event,
                                                         const gchar* new_comment);
EditEventCommentCommand* edit_event_comment_command_construct (GType object_type,
                                                               Event* event,
                                                               const gchar* new_comment);
gpointer command_manager_ref (gpointer instance);
void command_manager_unref (gpointer instance);
GParamSpec* param_spec_command_manager (const gchar* name,
                                        const gchar* nick,
                                        const gchar* blurb,
                                        GType object_type,
                                        GParamFlags flags);
void value_set_command_manager (GValue* value,
                                gpointer v_object);
void value_take_command_manager (GValue* value,
                                 gpointer v_object);
gpointer value_get_command_manager (const GValue* value);
GType command_manager_get_type (void) G_GNUC_CONST;
CommandManager* page_get_command_manager (Page* self);
void command_manager_execute (CommandManager* self,
                              Command* command);
GType media_source_get_type (void) G_GNUC_CONST;
gboolean event_set_primary_source (Event* self,
                                   MediaSource* source);
DataView* view_collection_get_selected_at (ViewCollection* self,
                                           gint index);
DataSource* data_view_get_source (DataView* self);
GType app_window_get_type (void) G_GNUC_CONST;
GType library_window_get_type (void) G_GNUC_CONST;
LibraryWindow* library_window_get_app (void);
void library_window_rename_event_in_sidebar (LibraryWindow* self,
                                             Event* event);
static void event_page_finalize (GObject * obj);
GType no_event_page_get_type (void) G_GNUC_CONST;
Alteration* alteration_new (const gchar* subject,
                            const gchar* detail);
Alteration* alteration_construct (GType object_type,
                                  const gchar* subject,
                                  const gchar* detail);
#define NO_EVENT_PAGE_NAME _ ("No Event")
NoEventPage* no_event_page_new (void);
NoEventPage* no_event_page_construct (GType object_type);
gpointer view_manager_ref (gpointer instance);
void view_manager_unref (gpointer instance);
GParamSpec* param_spec_view_manager (const gchar* name,
                                     const gchar* nick,
                                     const gchar* blurb,
                                     GType object_type,
                                     GParamFlags flags);
void value_set_view_manager (GValue* value,
                             gpointer v_object);
void value_take_view_manager (GValue* value,
                              gpointer v_object);
gpointer value_get_view_manager (const GValue* value);
GType view_manager_get_type (void) G_GNUC_CONST;
static NoEventPageNoEventViewManager* no_event_page_no_event_view_manager_new (NoEventPage* page);
static NoEventPageNoEventViewManager* no_event_page_no_event_view_manager_construct (GType object_type,
                                                                              NoEventPage* page);
GType collection_view_manager_get_type (void) G_GNUC_CONST;
static GType no_event_page_no_event_view_manager_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
gpointer view_collection_monitor_ref (gpointer instance);
void view_collection_monitor_unref (gpointer instance);
GParamSpec* view_collection_param_spec_monitor (const gchar* name,
                                                const gchar* nick,
                                                const gchar* blurb,
                                                GType object_type,
                                                GParamFlags flags);
void view_collection_value_set_monitor (GValue* value,
                                        gpointer v_object);
void view_collection_value_take_monitor (GValue* value,
                                         gpointer v_object);
gpointer view_collection_value_get_monitor (const GValue* value);
GType view_collection_monitor_get_type (void) G_GNUC_CONST;
ViewCollectionMonitor* view_collection_monitor_source_collection (ViewCollection* self,
                                                                  SourceCollection* sources,
                                                                  ViewManager* manager,
                                                                  Alteration* prereq,
                                                                  GeeCollection* initial,
                                                                  ProgressMonitor progress_monitor,
                                                                  void* progress_monitor_target);
GType media_source_collection_get_type (void) G_GNUC_CONST;
GType library_photo_source_collection_get_type (void) G_GNUC_CONST;
GType video_source_collection_get_type (void) G_GNUC_CONST;
static void no_event_page_real_get_config_photos_sort (MediaPage* base,
                                                gboolean* sort_order,
                                                gint* sort_by);
static void no_event_page_real_set_config_photos_sort (MediaPage* base,
                                                gboolean sort_order,
                                                gint sort_by);
CollectionViewManager* collection_view_manager_new (CollectionPage* page);
CollectionViewManager* collection_view_manager_construct (GType object_type,
                                                          CollectionPage* page);
static gboolean no_event_page_no_event_view_manager_real_include_in_view (ViewManager* base,
                                                                   DataSource* source);
GType event_id_get_type (void) G_GNUC_CONST;
EventID* event_id_dup (const EventID* self);
void event_id_free (EventID* self);
void media_source_get_event_id (MediaSource* self,
                                EventID* result);
#define EVENT_ID_INVALID ((gint64) -1)
gboolean view_manager_include_in_view (ViewManager* self,
                                       DataSource* source);
static void no_event_page_finalize (GObject * obj);

static const GActionEntry EVENT_PAGE_entries[3] = {{"MakePrimary", _event_page_on_make_primary_gsimple_action_activate_callback}, {"Rename", _event_page_on_rename_gsimple_action_activate_callback}, {"EditEventComment", _media_page_on_edit_comment_gsimple_action_activate_callback}};

static void
_event_page_on_events_altered_data_collection_items_altered (DataCollection* _sender,
                                                             GeeMap* items,
                                                             gpointer self)
{
#line 40 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	event_page_on_events_altered ((EventPage*) self, items);
#line 1072 "EventPage.c"
}


static void
_event_page_on_make_primary_gsimple_action_activate_callback (GSimpleAction* action,
                                                              GVariant* parameter,
                                                              gpointer self)
{
#line 50 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	event_page_on_make_primary ((EventPage*) self);
#line 1083 "EventPage.c"
}


static void
_event_page_on_rename_gsimple_action_activate_callback (GSimpleAction* action,
                                                        GVariant* parameter,
                                                        gpointer self)
{
#line 50 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	event_page_on_rename ((EventPage*) self);
#line 1094 "EventPage.c"
}


static void
_media_page_on_edit_comment_gsimple_action_activate_callback (GSimpleAction* action,
                                                              GVariant* parameter,
                                                              gpointer self)
{
#line 50 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	media_page_on_edit_comment ((MediaPage*) self);
#line 1105 "EventPage.c"
}


static gpointer
_g_object_ref0 (gpointer self)
{
#line 13 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	return self ? g_object_ref (self) : NULL;
#line 1114 "EventPage.c"
}


static DataView*
_media_page_create_thumbnail_create_view (DataSource* source,
                                          gpointer self)
{
	DataView* result;
	result = media_page_create_thumbnail ((MediaPage*) self, source);
#line 14 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	return result;
#line 1126 "EventPage.c"
}


EventPage*
event_page_construct (GType object_type,
                      Event* page_event)
{
	EventPage * self = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	Event* _tmp2_;
	ViewCollection* _tmp3_;
	ViewCollection* _tmp4_;
	EventSourceCollection* _tmp5_;
#line 10 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	g_return_val_if_fail (IS_EVENT (page_event), NULL);
#line 11 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp0_ = data_object_get_name (G_TYPE_CHECK_INSTANCE_CAST (page_event, TYPE_DATA_OBJECT, DataObject));
#line 11 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp1_ = _tmp0_;
#line 11 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	self = (EventPage*) collection_page_construct (object_type, _tmp1_);
#line 11 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_g_free0 (_tmp1_);
#line 13 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp2_ = _g_object_ref0 (page_event);
#line 13 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_g_object_unref0 (self->priv->page_event);
#line 13 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	self->priv->page_event = _tmp2_;
#line 14 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp3_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 14 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp4_ = _tmp3_;
#line 14 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	event_mirror_photos (page_event, _tmp4_, _media_page_create_thumbnail_create_view, G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_PAGE, MediaPage));
#line 14 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_data_collection_unref0 (_tmp4_);
#line 16 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	checkerboard_page_init_page_context_menu (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_CHECKERBOARD_PAGE, CheckerboardPage), "EventContextMenu");
#line 18 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp5_ = event_global;
#line 18 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, TYPE_DATA_COLLECTION, DataCollection), "items-altered", (GCallback) _event_page_on_events_altered_data_collection_items_altered, self, 0);
#line 10 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	return self;
#line 1173 "EventPage.c"
}


EventPage*
event_page_new (Event* page_event)
{
#line 10 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	return event_page_construct (TYPE_EVENT_PAGE, page_event);
#line 1182 "EventPage.c"
}


Event*
event_page_get_event (EventPage* self)
{
	Event* result = NULL;
	Event* _tmp0_;
	Event* _tmp1_;
#line 21 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	g_return_val_if_fail (IS_EVENT_PAGE (self), NULL);
#line 22 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp0_ = self->priv->page_event;
#line 22 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 22 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	result = _tmp1_;
#line 22 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	return result;
#line 1202 "EventPage.c"
}


static gboolean
event_page_real_on_app_key_pressed (Page* base,
                                    GdkEventKey* event)
{
	EventPage * self;
	gboolean result = FALSE;
	guint _tmp0_;
	const gchar* _tmp1_;
#line 25 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_EVENT_PAGE, EventPage);
#line 25 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 30 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp0_ = event->keyval;
#line 30 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp1_ = gdk_keyval_name (_tmp0_);
#line 30 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	if (g_strcmp0 (_tmp1_, "F2") == 0) {
#line 1224 "EventPage.c"
		ViewCollection* _tmp2_;
		ViewCollection* _tmp3_;
		gboolean _tmp4_;
#line 31 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		_tmp2_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 31 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		_tmp3_ = _tmp2_;
#line 31 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		_tmp4_ = view_collection_get_selected_count (_tmp3_) != 1;
#line 31 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		_data_collection_unref0 (_tmp3_);
#line 31 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		if (_tmp4_) {
#line 32 "/home/jens/Source/shotwell/src/events/EventPage.vala"
			result = TRUE;
#line 32 "/home/jens/Source/shotwell/src/events/EventPage.vala"
			return result;
#line 1242 "EventPage.c"
		}
	}
#line 36 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	result = PAGE_CLASS (event_page_parent_class)->on_app_key_pressed (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_COLLECTION_PAGE, CollectionPage), TYPE_PAGE, Page), event);
#line 36 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	return result;
#line 1249 "EventPage.c"
}


static void
event_page_real_init_collect_ui_filenames (Page* base,
                                           GeeList* ui_filenames)
{
	EventPage * self;
#line 44 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_EVENT_PAGE, EventPage);
#line 44 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	g_return_if_fail (GEE_IS_LIST (ui_filenames));
#line 45 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	PAGE_CLASS (event_page_parent_class)->init_collect_ui_filenames (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_COLLECTION_PAGE, CollectionPage), TYPE_PAGE, Page), ui_filenames);
#line 47 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	gee_collection_add (G_TYPE_CHECK_INSTANCE_CAST (ui_filenames, GEE_TYPE_COLLECTION, GeeCollection), "event.ui");
#line 1266 "EventPage.c"
}


static void
event_page_real_add_actions (Page* base,
                             GActionMap* map)
{
	EventPage * self;
#line 56 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_EVENT_PAGE, EventPage);
#line 56 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	g_return_if_fail (G_IS_ACTION_MAP (map));
#line 57 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	PAGE_CLASS (event_page_parent_class)->add_actions (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_COLLECTION_PAGE, CollectionPage), TYPE_PAGE, Page), map);
#line 59 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	g_action_map_add_action_entries (map, EVENT_PAGE_entries, G_N_ELEMENTS (EVENT_PAGE_entries), self);
#line 1283 "EventPage.c"
}


static void
event_page_real_remove_actions (Page* base,
                                GActionMap* map)
{
	EventPage * self;
#line 62 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_EVENT_PAGE, EventPage);
#line 62 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	g_return_if_fail (G_IS_ACTION_MAP (map));
#line 63 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	PAGE_CLASS (event_page_parent_class)->remove_actions (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_COLLECTION_PAGE, CollectionPage), TYPE_PAGE, Page), map);
#line 1298 "EventPage.c"
	{
		GActionEntry* entry_collection = NULL;
		gint entry_collection_length1 = 0;
		gint _entry_collection_size_ = 0;
		gint entry_it = 0;
#line 64 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		entry_collection = EVENT_PAGE_entries;
#line 64 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		entry_collection_length1 = G_N_ELEMENTS (EVENT_PAGE_entries);
#line 64 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		for (entry_it = 0; entry_it < G_N_ELEMENTS (EVENT_PAGE_entries); entry_it = entry_it + 1) {
#line 1310 "EventPage.c"
			GActionEntry entry = {0};
#line 64 "/home/jens/Source/shotwell/src/events/EventPage.vala"
			entry = entry_collection[entry_it];
#line 1314 "EventPage.c"
			{
				GActionEntry _tmp0_;
				const gchar* _tmp1_;
#line 65 "/home/jens/Source/shotwell/src/events/EventPage.vala"
				_tmp0_ = entry;
#line 65 "/home/jens/Source/shotwell/src/events/EventPage.vala"
				_tmp1_ = _tmp0_.name;
#line 65 "/home/jens/Source/shotwell/src/events/EventPage.vala"
				g_action_map_remove_action (map, _tmp1_);
#line 1324 "EventPage.c"
			}
		}
	}
}


static void
event_page_real_init_actions (Page* base,
                              gint selected_count,
                              gint count)
{
	EventPage * self;
#line 69 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_EVENT_PAGE, EventPage);
#line 70 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	PAGE_CLASS (event_page_parent_class)->init_actions (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_COLLECTION_PAGE, CollectionPage), TYPE_PAGE, Page), selected_count, count);
#line 1341 "EventPage.c"
}


static void
event_page_real_update_actions (Page* base,
                                gint selected_count,
                                gint count)
{
	EventPage * self;
#line 73 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_EVENT_PAGE, EventPage);
#line 74 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	page_set_action_sensitive (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page), "MakePrimary", selected_count == 1);
#line 77 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	page_set_action_sensitive (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page), "CommonJumpToEvent", FALSE);
#line 79 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	PAGE_CLASS (event_page_parent_class)->update_actions (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_COLLECTION_PAGE, CollectionPage), TYPE_PAGE, Page), selected_count, count);
#line 83 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	page_set_action_sensitive (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page), "EditEventComment", TRUE);
#line 1361 "EventPage.c"
}


static void
event_page_real_get_config_photos_sort (MediaPage* base,
                                        gboolean* sort_order,
                                        gint* sort_by)
{
	EventPage * self;
	gboolean _vala_sort_order = FALSE;
	gint _vala_sort_by = 0;
	ConfigFacade* _tmp0_;
	ConfigFacade* _tmp1_;
	gboolean _tmp2_ = FALSE;
	gint _tmp3_ = 0;
#line 86 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_EVENT_PAGE, EventPage);
#line 87 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp0_ = config_facade_get_instance ();
#line 87 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp1_ = _tmp0_;
#line 87 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	configuration_facade_get_event_photos_sort (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), &_tmp2_, &_tmp3_);
#line 87 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_vala_sort_order = _tmp2_;
#line 87 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_vala_sort_by = _tmp3_;
#line 87 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_g_object_unref0 (_tmp1_);
#line 86 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	if (sort_order) {
#line 86 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		*sort_order = _vala_sort_order;
#line 1395 "EventPage.c"
	}
#line 86 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	if (sort_by) {
#line 86 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		*sort_by = _vala_sort_by;
#line 1401 "EventPage.c"
	}
}


static void
event_page_real_set_config_photos_sort (MediaPage* base,
                                        gboolean sort_order,
                                        gint sort_by)
{
	EventPage * self;
	ConfigFacade* _tmp0_;
	ConfigFacade* _tmp1_;
#line 90 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_EVENT_PAGE, EventPage);
#line 91 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp0_ = config_facade_get_instance ();
#line 91 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp1_ = _tmp0_;
#line 91 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	configuration_facade_set_event_photos_sort (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), sort_order, sort_by);
#line 91 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_g_object_unref0 (_tmp1_);
#line 1424 "EventPage.c"
}


static void
event_page_on_events_altered (EventPage* self,
                              GeeMap* map)
{
	Event* _tmp0_;
#line 94 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	g_return_if_fail (IS_EVENT_PAGE (self));
#line 94 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	g_return_if_fail (GEE_IS_MAP (map));
#line 95 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp0_ = self->priv->page_event;
#line 95 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	if (gee_map_has_key (map, G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_DATA_OBJECT, DataObject))) {
#line 1441 "EventPage.c"
		Event* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
#line 96 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		_tmp1_ = self->priv->page_event;
#line 96 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		_tmp2_ = data_object_get_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_DATA_OBJECT, DataObject));
#line 96 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		_tmp3_ = _tmp2_;
#line 96 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		page_set_page_name (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page), _tmp3_);
#line 96 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		_g_free0 (_tmp3_);
#line 1455 "EventPage.c"
	}
}


static void
event_page_real_on_edit_comment (MediaPage* base)
{
	EventPage * self;
	ViewCollection* _tmp0_;
	ViewCollection* _tmp1_;
	gboolean _tmp2_;
#line 99 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_EVENT_PAGE, EventPage);
#line 100 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp0_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 100 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp1_ = _tmp0_;
#line 100 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp2_ = view_collection_get_selected_count (_tmp1_) == 0;
#line 100 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_data_collection_unref0 (_tmp1_);
#line 100 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	if (_tmp2_) {
#line 1479 "EventPage.c"
		EditCommentDialog* edit_comment_dialog = NULL;
		Event* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
		EditCommentDialog* _tmp6_;
		EditCommentDialog* _tmp7_;
		gchar* new_comment = NULL;
		EditCommentDialog* _tmp8_;
		gchar* _tmp9_;
		const gchar* _tmp10_;
		EditEventCommentCommand* command = NULL;
		Event* _tmp11_;
		const gchar* _tmp12_;
		EditEventCommentCommand* _tmp13_;
		CommandManager* _tmp14_;
		CommandManager* _tmp15_;
		EditEventCommentCommand* _tmp16_;
#line 101 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		_tmp3_ = self->priv->page_event;
#line 101 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		_tmp4_ = event_source_get_comment (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, TYPE_EVENT_SOURCE, EventSource));
#line 101 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		_tmp5_ = _tmp4_;
#line 101 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		_tmp6_ = edit_comment_dialog_new (_tmp5_, TRUE);
#line 101 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		_tmp7_ = _tmp6_;
#line 101 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		_g_free0 (_tmp5_);
#line 101 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		edit_comment_dialog = _tmp7_;
#line 103 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		_tmp8_ = edit_comment_dialog;
#line 103 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		_tmp9_ = edit_comment_dialog_execute (_tmp8_);
#line 103 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		new_comment = _tmp9_;
#line 104 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		_tmp10_ = new_comment;
#line 104 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		if (_tmp10_ == NULL) {
#line 105 "/home/jens/Source/shotwell/src/events/EventPage.vala"
			_g_free0 (new_comment);
#line 105 "/home/jens/Source/shotwell/src/events/EventPage.vala"
			_multi_text_entry_dialog_mediator_unref0 (edit_comment_dialog);
#line 105 "/home/jens/Source/shotwell/src/events/EventPage.vala"
			return;
#line 1527 "EventPage.c"
		}
#line 107 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		_tmp11_ = self->priv->page_event;
#line 107 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		_tmp12_ = new_comment;
#line 107 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		_tmp13_ = edit_event_comment_command_new (_tmp11_, _tmp12_);
#line 107 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		command = _tmp13_;
#line 108 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		_tmp14_ = page_get_command_manager (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 108 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		_tmp15_ = _tmp14_;
#line 108 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		_tmp16_ = command;
#line 108 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		command_manager_execute (_tmp15_, G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, TYPE_COMMAND, Command));
#line 108 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		_command_manager_unref0 (_tmp15_);
#line 109 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		_g_object_unref0 (command);
#line 109 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		_g_free0 (new_comment);
#line 109 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		_multi_text_entry_dialog_mediator_unref0 (edit_comment_dialog);
#line 109 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		return;
#line 1555 "EventPage.c"
	}
#line 112 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	MEDIA_PAGE_CLASS (event_page_parent_class)->on_edit_comment (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_COLLECTION_PAGE, CollectionPage), TYPE_MEDIA_PAGE, MediaPage));
#line 1559 "EventPage.c"
}


static void
event_page_on_make_primary (EventPage* self)
{
	ViewCollection* _tmp0_;
	ViewCollection* _tmp1_;
	gboolean _tmp2_;
	Event* _tmp3_;
	ViewCollection* _tmp4_;
	ViewCollection* _tmp5_;
	DataView* _tmp6_;
	DataView* _tmp7_;
	DataSource* _tmp8_;
	MediaSource* _tmp9_;
#line 115 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	g_return_if_fail (IS_EVENT_PAGE (self));
#line 116 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp0_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 116 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp1_ = _tmp0_;
#line 116 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp2_ = view_collection_get_selected_count (_tmp1_) != 1;
#line 116 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_data_collection_unref0 (_tmp1_);
#line 116 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	if (_tmp2_) {
#line 117 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		return;
#line 1590 "EventPage.c"
	}
#line 119 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp3_ = self->priv->page_event;
#line 119 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp4_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 119 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp5_ = _tmp4_;
#line 119 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp6_ = view_collection_get_selected_at (_tmp5_, 0);
#line 119 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp7_ = _tmp6_;
#line 119 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp8_ = data_view_get_source (_tmp7_);
#line 119 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp9_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, TYPE_MEDIA_SOURCE, MediaSource);
#line 119 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	event_set_primary_source (_tmp3_, _tmp9_);
#line 119 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_g_object_unref0 (_tmp9_);
#line 119 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_g_object_unref0 (_tmp7_);
#line 119 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_data_collection_unref0 (_tmp5_);
#line 1614 "EventPage.c"
}


static void
event_page_on_rename (EventPage* self)
{
	LibraryWindow* _tmp0_;
	LibraryWindow* _tmp1_;
	Event* _tmp2_;
#line 122 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	g_return_if_fail (IS_EVENT_PAGE (self));
#line 123 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp0_ = library_window_get_app ();
#line 123 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp1_ = _tmp0_;
#line 123 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp2_ = self->priv->page_event;
#line 123 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	library_window_rename_event_in_sidebar (_tmp1_, _tmp2_);
#line 123 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_g_object_unref0 (_tmp1_);
#line 1636 "EventPage.c"
}


static void
event_page_class_init (EventPageClass * klass)
{
#line 7 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	event_page_parent_class = g_type_class_peek_parent (klass);
#line 7 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	g_type_class_add_private (klass, sizeof (EventPagePrivate));
#line 7 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	((PageClass *) klass)->on_app_key_pressed = (gboolean (*) (Page *, GdkEventKey*)) event_page_real_on_app_key_pressed;
#line 7 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	((PageClass *) klass)->init_collect_ui_filenames = (void (*) (Page *, GeeList*)) event_page_real_init_collect_ui_filenames;
#line 7 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	((PageClass *) klass)->add_actions = (void (*) (Page *, GActionMap*)) event_page_real_add_actions;
#line 7 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	((PageClass *) klass)->remove_actions = (void (*) (Page *, GActionMap*)) event_page_real_remove_actions;
#line 7 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	((PageClass *) klass)->init_actions = (void (*) (Page *, gint, gint)) event_page_real_init_actions;
#line 7 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	((PageClass *) klass)->update_actions = (void (*) (Page *, gint, gint)) event_page_real_update_actions;
#line 7 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	((MediaPageClass *) klass)->get_config_photos_sort = (void (*) (MediaPage *, gboolean*, gint*)) event_page_real_get_config_photos_sort;
#line 7 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	((MediaPageClass *) klass)->set_config_photos_sort = (void (*) (MediaPage *, gboolean, gint)) event_page_real_set_config_photos_sort;
#line 7 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	((MediaPageClass *) klass)->on_edit_comment = (void (*) (MediaPage *)) event_page_real_on_edit_comment;
#line 7 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	G_OBJECT_CLASS (klass)->finalize = event_page_finalize;
#line 1667 "EventPage.c"
}


static void
event_page_instance_init (EventPage * self)
{
#line 7 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	self->priv = EVENT_PAGE_GET_PRIVATE (self);
#line 1676 "EventPage.c"
}


static void
event_page_finalize (GObject * obj)
{
	EventPage * self;
	EventSourceCollection* _tmp0_;
	guint _tmp1_;
	ViewCollection* _tmp2_;
	ViewCollection* _tmp3_;
#line 7 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_EVENT_PAGE, EventPage);
#line 40 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp0_ = event_global;
#line 40 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	g_signal_parse_name ("items-altered", TYPE_DATA_COLLECTION, &_tmp1_, NULL, FALSE);
#line 40 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_DATA_COLLECTION, DataCollection), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _event_page_on_events_altered_data_collection_items_altered, self);
#line 41 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp2_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 41 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp3_ = _tmp2_;
#line 41 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	view_collection_halt_mirroring (_tmp3_);
#line 41 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_data_collection_unref0 (_tmp3_);
#line 8 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_g_object_unref0 (self->priv->page_event);
#line 7 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	G_OBJECT_CLASS (event_page_parent_class)->finalize (obj);
#line 1708 "EventPage.c"
}


GType
event_page_get_type (void)
{
	static volatile gsize event_page_type_id__volatile = 0;
	if (g_once_init_enter (&event_page_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (EventPageClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) event_page_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (EventPage), 0, (GInstanceInitFunc) event_page_instance_init, NULL };
		GType event_page_type_id;
		event_page_type_id = g_type_register_static (TYPE_COLLECTION_PAGE, "EventPage", &g_define_type_info, 0);
		g_once_init_leave (&event_page_type_id__volatile, event_page_type_id);
	}
	return event_page_type_id__volatile;
}


NoEventPage*
no_event_page_construct (GType object_type)
{
	NoEventPage * self = NULL;
	ViewManager* filter = NULL;
	NoEventPageNoEventViewManager* _tmp0_;
	ViewCollection* _tmp1_;
	ViewCollection* _tmp2_;
	LibraryPhotoSourceCollection* _tmp3_;
	Alteration* _tmp4_;
	ViewCollectionMonitor* _tmp5_;
	ViewCollectionMonitor* _tmp6_;
	ViewCollection* _tmp7_;
	ViewCollection* _tmp8_;
	VideoSourceCollection* _tmp9_;
	Alteration* _tmp10_;
	ViewCollectionMonitor* _tmp11_;
	ViewCollectionMonitor* _tmp12_;
#line 146 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	self = (NoEventPage*) collection_page_construct (object_type, NO_EVENT_PAGE_NAME);
#line 148 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp0_ = no_event_page_no_event_view_manager_new (self);
#line 148 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	filter = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_VIEW_MANAGER, ViewManager);
#line 149 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp1_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 149 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp2_ = _tmp1_;
#line 149 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp3_ = library_photo_global;
#line 149 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp4_ = no_event_page_no_event_page_alteration;
#line 149 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp5_ = view_collection_monitor_source_collection (_tmp2_, G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, TYPE_SOURCE_COLLECTION, SourceCollection), filter, _tmp4_, NULL, NULL, NULL);
#line 149 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp6_ = _tmp5_;
#line 149 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_view_collection_monitor_unref0 (_tmp6_);
#line 149 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_data_collection_unref0 (_tmp2_);
#line 150 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp7_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 150 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp8_ = _tmp7_;
#line 150 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp9_ = video_global;
#line 150 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp10_ = no_event_page_no_event_page_alteration;
#line 150 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp11_ = view_collection_monitor_source_collection (_tmp8_, G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, TYPE_SOURCE_COLLECTION, SourceCollection), filter, _tmp10_, NULL, NULL, NULL);
#line 150 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp12_ = _tmp11_;
#line 150 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_view_collection_monitor_unref0 (_tmp12_);
#line 150 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_data_collection_unref0 (_tmp8_);
#line 145 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_view_manager_unref0 (filter);
#line 145 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	return self;
#line 1786 "EventPage.c"
}


NoEventPage*
no_event_page_new (void)
{
#line 145 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	return no_event_page_construct (TYPE_NO_EVENT_PAGE);
#line 1795 "EventPage.c"
}


static void
no_event_page_real_get_config_photos_sort (MediaPage* base,
                                           gboolean* sort_order,
                                           gint* sort_by)
{
	NoEventPage * self;
	gboolean _vala_sort_order = FALSE;
	gint _vala_sort_by = 0;
	ConfigFacade* _tmp0_;
	ConfigFacade* _tmp1_;
	gboolean _tmp2_ = FALSE;
	gint _tmp3_ = 0;
#line 153 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_NO_EVENT_PAGE, NoEventPage);
#line 154 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp0_ = config_facade_get_instance ();
#line 154 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp1_ = _tmp0_;
#line 154 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	configuration_facade_get_event_photos_sort (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), &_tmp2_, &_tmp3_);
#line 154 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_vala_sort_order = _tmp2_;
#line 154 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_vala_sort_by = _tmp3_;
#line 154 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_g_object_unref0 (_tmp1_);
#line 153 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	if (sort_order) {
#line 153 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		*sort_order = _vala_sort_order;
#line 1829 "EventPage.c"
	}
#line 153 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	if (sort_by) {
#line 153 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		*sort_by = _vala_sort_by;
#line 1835 "EventPage.c"
	}
}


static void
no_event_page_real_set_config_photos_sort (MediaPage* base,
                                           gboolean sort_order,
                                           gint sort_by)
{
	NoEventPage * self;
	ConfigFacade* _tmp0_;
	ConfigFacade* _tmp1_;
#line 157 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_NO_EVENT_PAGE, NoEventPage);
#line 158 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp0_ = config_facade_get_instance ();
#line 158 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp1_ = _tmp0_;
#line 158 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	configuration_facade_set_event_photos_sort (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), sort_order, sort_by);
#line 158 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_g_object_unref0 (_tmp1_);
#line 1858 "EventPage.c"
}


static NoEventPageNoEventViewManager*
no_event_page_no_event_view_manager_construct (GType object_type,
                                               NoEventPage* page)
{
	NoEventPageNoEventViewManager* self = NULL;
#line 132 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	g_return_val_if_fail (IS_NO_EVENT_PAGE (page), NULL);
#line 133 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	self = (NoEventPageNoEventViewManager*) collection_view_manager_construct (object_type, G_TYPE_CHECK_INSTANCE_CAST (page, TYPE_COLLECTION_PAGE, CollectionPage));
#line 132 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	return self;
#line 1873 "EventPage.c"
}


static NoEventPageNoEventViewManager*
no_event_page_no_event_view_manager_new (NoEventPage* page)
{
#line 132 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	return no_event_page_no_event_view_manager_construct (NO_EVENT_PAGE_TYPE_NO_EVENT_VIEW_MANAGER, page);
#line 1882 "EventPage.c"
}


static gboolean
no_event_page_no_event_view_manager_real_include_in_view (ViewManager* base,
                                                          DataSource* source)
{
	NoEventPageNoEventViewManager * self;
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	EventID _tmp1_ = {0};
	gint64 _tmp2_;
#line 137 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, NO_EVENT_PAGE_TYPE_NO_EVENT_VIEW_MANAGER, NoEventPageNoEventViewManager);
#line 137 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	g_return_val_if_fail (IS_DATA_SOURCE (source), FALSE);
#line 138 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	media_source_get_event_id (G_TYPE_CHECK_INSTANCE_CAST (source, TYPE_MEDIA_SOURCE, MediaSource), &_tmp1_);
#line 138 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp2_ = _tmp1_.id;
#line 138 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	if (_tmp2_ != EVENT_ID_INVALID) {
#line 138 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		_tmp0_ = FALSE;
#line 1907 "EventPage.c"
	} else {
#line 139 "/home/jens/Source/shotwell/src/events/EventPage.vala"
		_tmp0_ = VIEW_MANAGER_CLASS (no_event_page_no_event_view_manager_parent_class)->include_in_view (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_COLLECTION_VIEW_MANAGER, CollectionViewManager), TYPE_VIEW_MANAGER, ViewManager), source);
#line 1911 "EventPage.c"
	}
#line 138 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	result = _tmp0_;
#line 138 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	return result;
#line 1917 "EventPage.c"
}


static void
no_event_page_no_event_view_manager_class_init (NoEventPageNoEventViewManagerClass * klass)
{
#line 131 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	no_event_page_no_event_view_manager_parent_class = g_type_class_peek_parent (klass);
#line 131 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	((ViewManagerClass *) klass)->include_in_view = (gboolean (*) (ViewManager *, DataSource*)) no_event_page_no_event_view_manager_real_include_in_view;
#line 1928 "EventPage.c"
}


static void
no_event_page_no_event_view_manager_instance_init (NoEventPageNoEventViewManager * self)
{
}


static GType
no_event_page_no_event_view_manager_get_type (void)
{
	static volatile gsize no_event_page_no_event_view_manager_type_id__volatile = 0;
	if (g_once_init_enter (&no_event_page_no_event_view_manager_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (NoEventPageNoEventViewManagerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) no_event_page_no_event_view_manager_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (NoEventPageNoEventViewManager), 0, (GInstanceInitFunc) no_event_page_no_event_view_manager_instance_init, NULL };
		GType no_event_page_no_event_view_manager_type_id;
		no_event_page_no_event_view_manager_type_id = g_type_register_static (TYPE_COLLECTION_VIEW_MANAGER, "NoEventPageNoEventViewManager", &g_define_type_info, 0);
		g_once_init_leave (&no_event_page_no_event_view_manager_type_id__volatile, no_event_page_no_event_view_manager_type_id);
	}
	return no_event_page_no_event_view_manager_type_id__volatile;
}


static void
no_event_page_class_init (NoEventPageClass * klass)
{
	Alteration* _tmp0_;
#line 127 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	no_event_page_parent_class = g_type_class_peek_parent (klass);
#line 127 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	((MediaPageClass *) klass)->get_config_photos_sort = (void (*) (MediaPage *, gboolean*, gint*)) no_event_page_real_get_config_photos_sort;
#line 127 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	((MediaPageClass *) klass)->set_config_photos_sort = (void (*) (MediaPage *, gboolean, gint)) no_event_page_real_set_config_photos_sort;
#line 127 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	G_OBJECT_CLASS (klass)->finalize = no_event_page_finalize;
#line 143 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	_tmp0_ = alteration_new ("metadata", "event");
#line 143 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	no_event_page_no_event_page_alteration = _tmp0_;
#line 1968 "EventPage.c"
}


static void
no_event_page_instance_init (NoEventPage * self)
{
}


static void
no_event_page_finalize (GObject * obj)
{
	NoEventPage * self;
#line 127 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_NO_EVENT_PAGE, NoEventPage);
#line 127 "/home/jens/Source/shotwell/src/events/EventPage.vala"
	G_OBJECT_CLASS (no_event_page_parent_class)->finalize (obj);
#line 1986 "EventPage.c"
}


GType
no_event_page_get_type (void)
{
	static volatile gsize no_event_page_type_id__volatile = 0;
	if (g_once_init_enter (&no_event_page_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (NoEventPageClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) no_event_page_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (NoEventPage), 0, (GInstanceInitFunc) no_event_page_instance_init, NULL };
		GType no_event_page_type_id;
		no_event_page_type_id = g_type_register_static (TYPE_COLLECTION_PAGE, "NoEventPage", &g_define_type_info, 0);
		g_once_init_leave (&no_event_page_type_id__volatile, no_event_page_type_id);
	}
	return no_event_page_type_id__volatile;
}



